Module: Google::Apis::CloudproductregistryV1
- Defined in:
- lib/google/apis/cloudproductregistry_v1.rb,
lib/google/apis/cloudproductregistry_v1/classes.rb,
lib/google/apis/cloudproductregistry_v1/service.rb,
lib/google/apis/cloudproductregistry_v1/gem_version.rb,
lib/google/apis/cloudproductregistry_v1/representations.rb
Overview
Cloud Product Registry API
cloudproductregistry.googleapis.com API.
Defined Under Namespace
Classes: CloudProductRegistryService, ListLogicalProductVariantsResponse, ListLogicalProductsResponse, ListProductSuitesResponse, LogicalProduct, LogicalProductVariant, LookupEntityResponse, ProductSuite
Constant Summary collapse
- GEM_VERSION =
Version of the google-apis-cloudproductregistry_v1 gem
"0.1.0"- GENERATOR_VERSION =
Version of the code generator used to generate this client
"0.19.0"- REVISION =
Revision of the discovery document this client was generated from
"20260611"- VERSION =
Version of the Cloud Product Registry API this client connects to. This is NOT the gem version.
'V1'