Class: Google::Apis::CloudproductregistryV1::LogicalProduct
- Inherits:
-
Object
- Object
- Google::Apis::CloudproductregistryV1::LogicalProduct
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudproductregistry_v1/classes.rb,
lib/google/apis/cloudproductregistry_v1/representations.rb,
lib/google/apis/cloudproductregistry_v1/representations.rb
Overview
Represents an independent service offering that can be provisioned by a customer.
Instance Attribute Summary collapse
-
#lifecycle_state ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#product_suite ⇒ String
Product suite associated with the logical product.
-
#replaced ⇒ Boolean
(also: #replaced?)
Output only.
-
#replacement ⇒ String
Output only.
-
#title ⇒ String
Display name of the LogicalProduct.
-
#variants ⇒ Array<String>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LogicalProduct
constructor
A new instance of LogicalProduct.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LogicalProduct
Returns a new instance of LogicalProduct.
153 154 155 |
# File 'lib/google/apis/cloudproductregistry_v1/classes.rb', line 153 def initialize(**args) update!(**args) end |
Instance Attribute Details
#lifecycle_state ⇒ String
Output only. Current Lifecycle state of the logical product.
Corresponds to the JSON property lifecycleState
111 112 113 |
# File 'lib/google/apis/cloudproductregistry_v1/classes.rb', line 111 def lifecycle_state @lifecycle_state end |
#name ⇒ String
Identifier. The resource name of the LogicalProduct. Format: logicalProducts/
logical_product.
Corresponds to the JSON property name
117 118 119 |
# File 'lib/google/apis/cloudproductregistry_v1/classes.rb', line 117 def name @name end |
#product_suite ⇒ String
Product suite associated with the logical product. Format: productSuites/
product_suite.
Corresponds to the JSON property productSuite
123 124 125 |
# File 'lib/google/apis/cloudproductregistry_v1/classes.rb', line 123 def product_suite @product_suite end |
#replaced ⇒ Boolean Also known as: replaced?
Output only. Indicates whether the logical product has been replaced. If
false, the product is active. If true, the product has been replaced by
another type, and the replacement field contains the resource name of that
replacement.
Corresponds to the JSON property replaced
131 132 133 |
# File 'lib/google/apis/cloudproductregistry_v1/classes.rb', line 131 def replaced @replaced end |
#replacement ⇒ String
Output only. The resource name of the Logical Entity that the logical product
is replaced by. This field is only populated when this logical product is
replaced by some other type. Eg: logicalProducts/logical_product/variants/
variant, productSuites/product_suite, etc.
Corresponds to the JSON property replacement
140 141 142 |
# File 'lib/google/apis/cloudproductregistry_v1/classes.rb', line 140 def replacement @replacement end |
#title ⇒ String
Display name of the LogicalProduct.
Corresponds to the JSON property title
145 146 147 |
# File 'lib/google/apis/cloudproductregistry_v1/classes.rb', line 145 def title @title end |
#variants ⇒ Array<String>
Output only. Child variant resource references. Format: logicalProducts/
logical_product/variants/variant
Corresponds to the JSON property variants
151 152 153 |
# File 'lib/google/apis/cloudproductregistry_v1/classes.rb', line 151 def variants @variants end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
158 159 160 161 162 163 164 165 166 |
# File 'lib/google/apis/cloudproductregistry_v1/classes.rb', line 158 def update!(**args) @lifecycle_state = args[:lifecycle_state] if args.key?(:lifecycle_state) @name = args[:name] if args.key?(:name) @product_suite = args[:product_suite] if args.key?(:product_suite) @replaced = args[:replaced] if args.key?(:replaced) @replacement = args[:replacement] if args.key?(:replacement) @title = args[:title] if args.key?(:title) @variants = args[:variants] if args.key?(:variants) end |