Class: Google::Apis::CloudproductregistryV1::LogicalProductVariant
- Inherits:
-
Object
- Object
- Google::Apis::CloudproductregistryV1::LogicalProductVariant
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudproductregistry_v1/classes.rb,
lib/google/apis/cloudproductregistry_v1/representations.rb,
lib/google/apis/cloudproductregistry_v1/representations.rb
Overview
Represents a distinct offering derived from a primary product that retains core functionalities but offers specialized features for a specific market segment.
Instance Attribute Summary collapse
-
#lifecycle_state ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#replaced ⇒ Boolean
(also: #replaced?)
Output only.
-
#replacement ⇒ String
Output only.
-
#title ⇒ String
Display name of the LogicalProductVariant.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LogicalProductVariant
constructor
A new instance of LogicalProductVariant.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LogicalProductVariant
Returns a new instance of LogicalProductVariant.
208 209 210 |
# File 'lib/google/apis/cloudproductregistry_v1/classes.rb', line 208 def initialize(**args) update!(**args) end |
Instance Attribute Details
#lifecycle_state ⇒ String
Output only. Current Lifecycle state of the logical product variant.
Corresponds to the JSON property lifecycleState
178 179 180 |
# File 'lib/google/apis/cloudproductregistry_v1/classes.rb', line 178 def lifecycle_state @lifecycle_state end |
#name ⇒ String
Identifier. The resource name of the LogicalProductVariant. Format:
logicalProducts/logical_product/variants/variant
Corresponds to the JSON property name
184 185 186 |
# File 'lib/google/apis/cloudproductregistry_v1/classes.rb', line 184 def name @name end |
#replaced ⇒ Boolean Also known as: replaced?
Output only. Indicates whether the logical product variant has been replaced.
If false, the variant is active. If true, the variant has been replaced by
another type, and the replacement field contains the resource name of that
replacement.
Corresponds to the JSON property replaced
192 193 194 |
# File 'lib/google/apis/cloudproductregistry_v1/classes.rb', line 192 def replaced @replaced end |
#replacement ⇒ String
Output only. The resource name of the Logical Entity that the logical product
variant is replaced by. This field is only populated when this logical product
variant is replaced by some other type. Eg: logicalProducts/logical_product,
productSuites/product_suite, etc.
Corresponds to the JSON property replacement
201 202 203 |
# File 'lib/google/apis/cloudproductregistry_v1/classes.rb', line 201 def replacement @replacement end |
#title ⇒ String
Display name of the LogicalProductVariant.
Corresponds to the JSON property title
206 207 208 |
# File 'lib/google/apis/cloudproductregistry_v1/classes.rb', line 206 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
213 214 215 216 217 218 219 |
# File 'lib/google/apis/cloudproductregistry_v1/classes.rb', line 213 def update!(**args) @lifecycle_state = args[:lifecycle_state] if args.key?(:lifecycle_state) @name = args[:name] if args.key?(:name) @replaced = args[:replaced] if args.key?(:replaced) @replacement = args[:replacement] if args.key?(:replacement) @title = args[:title] if args.key?(:title) end |