Class: Google::Apis::CloudproductregistryV1::LookupEntityResponse
- Inherits:
-
Object
- Object
- Google::Apis::CloudproductregistryV1::LookupEntityResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudproductregistry_v1/classes.rb,
lib/google/apis/cloudproductregistry_v1/representations.rb,
lib/google/apis/cloudproductregistry_v1/representations.rb
Overview
Response message for LookupEntity.
Instance Attribute Summary collapse
-
#logical_product ⇒ Google::Apis::CloudproductregistryV1::LogicalProduct
Represents an independent service offering that can be provisioned by a customer.
-
#logical_product_variant ⇒ Google::Apis::CloudproductregistryV1::LogicalProductVariant
Represents a distinct offering derived from a primary product that retains core functionalities but offers specialized features for a specific market segment.
-
#product_suite ⇒ Google::Apis::CloudproductregistryV1::ProductSuite
Represents a unified grouping of products sharing a common brand and market positioning.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LookupEntityResponse
constructor
A new instance of LookupEntityResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LookupEntityResponse
Returns a new instance of LookupEntityResponse.
245 246 247 |
# File 'lib/google/apis/cloudproductregistry_v1/classes.rb', line 245 def initialize(**args) update!(**args) end |
Instance Attribute Details
#logical_product ⇒ Google::Apis::CloudproductregistryV1::LogicalProduct
Represents an independent service offering that can be provisioned by a
customer.
Corresponds to the JSON property logicalProduct
230 231 232 |
# File 'lib/google/apis/cloudproductregistry_v1/classes.rb', line 230 def logical_product @logical_product end |
#logical_product_variant ⇒ Google::Apis::CloudproductregistryV1::LogicalProductVariant
Represents a distinct offering derived from a primary product that retains
core functionalities but offers specialized features for a specific market
segment.
Corresponds to the JSON property logicalProductVariant
237 238 239 |
# File 'lib/google/apis/cloudproductregistry_v1/classes.rb', line 237 def logical_product_variant @logical_product_variant end |
#product_suite ⇒ Google::Apis::CloudproductregistryV1::ProductSuite
Represents a unified grouping of products sharing a common brand and market
positioning.
Corresponds to the JSON property productSuite
243 244 245 |
# File 'lib/google/apis/cloudproductregistry_v1/classes.rb', line 243 def product_suite @product_suite end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
250 251 252 253 254 |
# File 'lib/google/apis/cloudproductregistry_v1/classes.rb', line 250 def update!(**args) @logical_product = args[:logical_product] if args.key?(:logical_product) @logical_product_variant = args[:logical_product_variant] if args.key?(:logical_product_variant) @product_suite = args[:product_suite] if args.key?(:product_suite) end |