Class: Google::Apis::CloudproductregistryV1::ProductSuite
- Inherits:
-
Object
- Object
- Google::Apis::CloudproductregistryV1::ProductSuite
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudproductregistry_v1/classes.rb,
lib/google/apis/cloudproductregistry_v1/representations.rb,
lib/google/apis/cloudproductregistry_v1/representations.rb
Overview
Represents a unified grouping of products sharing a common brand and market positioning.
Instance Attribute Summary collapse
-
#logical_products ⇒ Array<String>
Output only.
-
#name ⇒ String
Identifier.
-
#replaced ⇒ Boolean
(also: #replaced?)
Output only.
-
#replacement ⇒ String
Output only.
-
#title ⇒ String
Title of the ProductSuite.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProductSuite
constructor
A new instance of ProductSuite.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProductSuite
Returns a new instance of ProductSuite.
296 297 298 |
# File 'lib/google/apis/cloudproductregistry_v1/classes.rb', line 296 def initialize(**args) update!(**args) end |
Instance Attribute Details
#logical_products ⇒ Array<String>
Output only. LogicalProducts under this suite. Format: logicalProducts/
logical_product
Corresponds to the JSON property logicalProducts
266 267 268 |
# File 'lib/google/apis/cloudproductregistry_v1/classes.rb', line 266 def logical_products @logical_products end |
#name ⇒ String
Identifier. The resource name of the ProductSuite. Format: productSuites/
product_suite
Corresponds to the JSON property name
272 273 274 |
# File 'lib/google/apis/cloudproductregistry_v1/classes.rb', line 272 def name @name end |
#replaced ⇒ Boolean Also known as: replaced?
Output only. Indicates whether the product suite has been replaced. If false,
the product suite is active. If true, the product suite has been replaced
by another type, and the replacement field contains the resource name of
that replacement.
Corresponds to the JSON property replaced
280 281 282 |
# File 'lib/google/apis/cloudproductregistry_v1/classes.rb', line 280 def replaced @replaced end |
#replacement ⇒ String
Output only. The resource name of the Logical Entity that the product suite is
replaced by. This field is only populated when this product suite is replaced
by some other type. Eg: logicalProducts/logical_product, logicalProducts/
logical_product/variants/variant, etc.
Corresponds to the JSON property replacement
289 290 291 |
# File 'lib/google/apis/cloudproductregistry_v1/classes.rb', line 289 def replacement @replacement end |
#title ⇒ String
Title of the ProductSuite.
Corresponds to the JSON property title
294 295 296 |
# File 'lib/google/apis/cloudproductregistry_v1/classes.rb', line 294 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
301 302 303 304 305 306 307 |
# File 'lib/google/apis/cloudproductregistry_v1/classes.rb', line 301 def update!(**args) @logical_products = args[:logical_products] if args.key?(:logical_products) @name = args[:name] if args.key?(:name) @replaced = args[:replaced] if args.key?(:replaced) @replacement = args[:replacement] if args.key?(:replacement) @title = args[:title] if args.key?(:title) end |